==> gmssl-jsse-provider-0.1.4-20190730.152528-2-sources.jar: org/bouncycastle/tls/crypto/impl/bc/BcTlsCryptoProvider.java <==
package org.bouncycastle.tls.crypto.impl.bc;

import com.xdja.pki.gmssl.crypto.sdf.SdfCryptoType;
import com.xdja.pki.gmssl.crypto.sdf.SdfRandom;
import com.xdja.pki.gmssl.sdf.SdfSDK;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.tls.crypto.TlsCrypto;
import org.bouncycastle.tls.crypto.TlsCryptoProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import java.security.SecureRandom;

/**
 * Basic builder class for constructing standard TlsCrypto classes.
 */
public class BcTlsCryptoProvider implements TlsCryptoProvider {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    private GMSSLCryptoType type;

    public BcTlsCryptoProvider() {
        this.type = GMSSLCryptoType.BC;
    }

    public void setType(GMSSLCryptoType type) {
        this.type = type;
    }

    /**
     * Create a new TlsCrypto using the current builder configuration and the passed in entropy source..
     *
     * @param random SecureRandom for generating key material and seeds for nonce generation.
     * @return a new TlsCrypto.
     */
    @Override
    public TlsCrypto create(SecureRandom random) {
        logger.debug("create TlsCrypto type " + this.type);
        switch (this.type) {
            case BC:
                try {
                    if (random == null) {
                        // TODO: 2019/4/3 DEFAULT will be waiting...
                        random = SecureRandom.getInstance("SHA1PRNG");
                    }
                    return new BcTlsCrypto(random);
                } catch (NoSuchAlgorithmException e) {
                    throw new IllegalStateException("unable to create TlsCrypto: " + e.getMessage(), e);
                }
            case SDF_PCIE:
                return new BcTlsCryptoSdf(SdfCryptoType.PCIE);
            case SDF_YUNHSM:
                return new BcTlsCryptoSdf(SdfCryptoType.YUNHSM);
            default:
                throw new IllegalStateException("unable to create TlsCrypto: " + this.type, null);
        }
    }

    /**
     * Create a new TlsCrypto using the current builder configuration.
     *
     * @param keyRandom   SecureRandom for generating key material.
     * @param nonceRandom SecureRandom for generating nonces.
     * @return a new TlsCrypto.
     */
    @Override
    public TlsCrypto create(SecureRandom keyRandom, SecureRandom nonceRandom) {
        return create(keyRandom);
    }

    //GMSSL SUPPORT add pki
    public Provider getPkixProvider() {
        return new BouncyCastleProvider();
    }
}

==> gmssl-jsse-provider-0.2.0-20190826.095025-1-sources.jar: org/bouncycastle/tls/crypto/impl/bc/BcTlsCryptoProvider.java <==
package org.bouncycastle.tls.crypto.impl.bc;

import com.xdja.pki.gmssl.crypto.sdf.SdfCryptoType;
import com.xdja.pki.gmssl.crypto.sdf.SdfRandom;
import com.xdja.pki.gmssl.sdf.SdfSDK;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.tls.crypto.TlsCrypto;
import org.bouncycastle.tls.crypto.TlsCryptoProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import java.security.SecureRandom;

/**
 * Basic builder class for constructing standard TlsCrypto classes.
 */
public class BcTlsCryptoProvider implements TlsCryptoProvider {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    private GMSSLCryptoType type;

    public BcTlsCryptoProvider() {
        this.type = GMSSLCryptoType.BC;
    }

    public void setType(GMSSLCryptoType type) {
        this.type = type;
    }

    /**
     * Create a new TlsCrypto using the current builder configuration and the passed in entropy source..
     *
     * @param random SecureRandom for generating key material and seeds for nonce generation.
     * @return a new TlsCrypto.
     */
    @Override
    public TlsCrypto create(SecureRandom random) {
        logger.debug("create TlsCrypto type " + this.type);
        switch (this.type) {
            case BC:
                try {
                    if (random == null) {
                        // TODO: 2019/4/3 DEFAULT will be waiting...
                        random = SecureRandom.getInstance("DEFAULT");
                    }
                    return new BcTlsCrypto(random);
                } catch (NoSuchAlgorithmException e) {
                    throw new IllegalStateException("unable to create TlsCrypto: " + e.getMessage(), e);
                }
            case SDF_PCIE:
                return new BcTlsCryptoSdf(SdfCryptoType.PCIE);
            case SDF_YUNHSM:
                return new BcTlsCryptoSdf(SdfCryptoType.YUNHSM);
            default:
                throw new IllegalStateException("unable to create TlsCrypto: " + this.type, null);
        }
    }

    /**
     * Create a new TlsCrypto using the current builder configuration.
     *
     * @param keyRandom   SecureRandom for generating key material.
     * @param nonceRandom SecureRandom for generating nonces.
     * @return a new TlsCrypto.
     */
    @Override
    public TlsCrypto create(SecureRandom keyRandom, SecureRandom nonceRandom) {
        return create(keyRandom);
    }

    //GMSSL SUPPORT add pki
    public Provider getPkixProvider() {
        return new BouncyCastleProvider();
    }
}
